@@ -36,12 +36,13 @@ vblpcmKL<-function(x)
   nu<-x$nu
   alpha<-x$alpha
   inv_sigma02<-x$inv_sigma02
+  seed<-x$seed
   NC=x$NC
   KL=0
   imodel=switch(model, plain=0, rsender=1, rreceiver=2, rsocial=3)
   total_KL<-function(imodel, P_n, P_e, D, N, NE, NnonE, NM, G, Y, E, nonE, M, numedges, EnonE, diam, hopslist, XX_e, 
                      V_xi_n, V_xi_e, V_psi2_n, V_psi2_e, V_z, V_sigma2, V_eta, V_lambda, V_omega2, V_nu, V_alpha, xi, 
-                     psi2, sigma02, omega2, nu, alpha, inv_sigma02, NC, KL) 
+                     psi2, sigma02, omega2, nu, alpha, inv_sigma02, seed, NC, KL) 
   		     {
                      ans<-.C("KL_total", NAOK=TRUE, 
                      imodel=as.integer(imodel), P_n=as.integer(P_n),P_e=as.integer(P_e),D=as.integer(d), N=as.integer(N), 
@@ -55,13 +56,13 @@ vblpcmKL<-function(x)
                      V_omega2=as.double(V_omega2), V_nu=as.double(V_nu), V_alpha=as.double(V_alpha),
                      xi=as.double(xi), psi2=as.double(psi2), sigma02=as.double(sigma02),
                      omega2=as.double(omega2), nu=as.double(nu), alpha=as.double(alpha),
-                     inv_sigma02=as.double(inv_sigma02), 
+                     inv_sigma02=as.double(inv_sigma02), seed=as.double(seed),
   		     NC=as.integer(NC), KL=as.double(KL), PACKAGE="VBLPCM")
                      return(ans)
                      }
   final_KL<-total_KL(imodel, P_n, P_e, d, N, NE, NnonE, NM, G, Y, E, nonE, M, numedges, EnonE, diam, hopslist, XX_e, V_xi_n, V_xi_e, 
                      V_psi2_n, V_psi2_e, V_z, V_sigma2, V_eta, V_lambda, V_omega2, V_nu, V_alpha, xi, psi2, sigma02, omega2, nu, alpha,
-  		     inv_sigma02, NC, KL)
+  		     inv_sigma02, seed, NC, KL)
   cat("KL distance to true posterior is ", final_KL$KL, "+ constant \n")
   final_KL$KL
   }
